<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Pro zastavení záznamu klepněte na ikonu
v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>V průběhu nahrávání neotáčejte obrazovku</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nahrávání</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Pořídit snímek obrazovky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zachytávání obrazovky</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ukládání se nezdařilo. Uložte ho do své domovské složky.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Pořizování snímku dokončeno</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Vyberte oblast</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ukládání souboru se záznamem obrazovky – čekejte prosím…</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Protože v průběhu byl vypnutý efekt pro okno, nahrávání bylo zastaveno</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Pořízení snímku obrazovky se nezdařilo.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Snímek z celého posuvníku</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Připnout snímky obrazovky</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Obrazec byl dokončen a zkopírován do schránky</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Připnout snímky obrazovky</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Zaznamenat</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Obrazec</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Záznam</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Záznam dokončen</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otevřít složku</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Zaznamenávání obrazovky se spustí za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Získat nápovědu.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Nepodařilo se pořídit pokračující snímek obrazovky.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Dosaženo spodního okraje oblasti posouvání</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Dosaženo nejvyšší možné délky</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>upravit oblast zachytávání</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Pokud chcete pořídit snímek posouvaného obsahu, otáčejte kolečkem myši nebo klepněte</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Snižte rychlost posouvání</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Neplatná oblast, klepněte na </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Sem zadejte text</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Spustit/Pořídit snímek obrazovky</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Opustit/Uložit</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Upravení velikosti</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Rychlé spuštění</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Snímek okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Pořídit snímek s prodlevou</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Roztáhnout nahoru</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Roztáhnout dolů</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Roztáhnout doleva</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Roztáhnout doprava</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Ubrat výšku nahoře</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Ubrat výšku dole</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Ubrat šířku nalevo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Ubrat šířku napravo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Stisknutí klávesy</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webová kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Spustit záznam</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Spustit/Zaznamenávání</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Myš</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Rozpoznat text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Snímek z celého posuvníku</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Připnout snímky obrazovky</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Spustit rozpoznávání textu</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Spustit pořizování snímků obrazovky</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Zaznamenat</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Obdélník
Stiskněte a podržte klávesu Shift pro kreslení čtverce</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipsa
Stiskněte a podržte klávesu Shift pro kreslení kruhu</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Štětec
Stiskněte a podržte klávesu Shift pro kreslení přímky</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Nastavení síly rozmazání (posunutím ji nastavíte)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Nastavení velikosti štětce (posunutím ji nastavíte)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Nastavení velikosti textu (posunutím ji nastavíte)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Klepněte nebo táhněte
pro vybrání oblasti k nahrávání</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Ukázat stisknutí klávesy (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Skrýt stisknutí klávesy (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Ukázat stisknutí klávesy (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Zapnout kameru (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Vypnout kameru (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Nastavení (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>SN/S:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 snímků/s</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 snímků/s</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 snímků/s</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 snímků/s</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 snímků/s</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Zvuk systému</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zobrazit ukazatel</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Zobrazit kliknutí</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Uložit do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Obdélník (R)
Stiskněte a podržte klávesu Shift pro kreslení čtverce</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Elipsa (O)
Stiskněte a podržte klávesu Shift pro kreslení kruhu</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Čára (L)
Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné čáry</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Šipka (X)
Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipky</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Tužka (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Rozmazání (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Snímek z celého posuvníku (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Vytáhnout text (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Připnout snímky obrazovky (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Zpět (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Nastavit popis umístění při ukládání</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Změnit popis umístění pro ukládání</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efekty orámování</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Stín</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Okraj</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Rozpoznat text</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Zavřít (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Upravte oblast nahrávání v %1*%2 a získejte tak lepší video efekt</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>V tuto chvíli není zaznamenávání obrazovky podporováno</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Nová nahrávka</translation>
    </message>
</context>
</TS>
